@@ -2,7 +2,7 @@
 
 import os
 import tempfile
-from typing import Any, Dict
+from typing import Any, Dict, Optional
 
 import yaml
 
@@ -15,18 +15,12 @@ def mkdtemp_in_build_dir():
     return tempfile.mkdtemp(dir=build_tmp_dir)
 
 
-def build_hygienic_bin_path(parent=None, child=None):
-    """Get the hygienic bin directory, optionally from `parent` and with `child`."""
-    pjoin = os.path.join
-    res = pjoin("dist-test", "bin")
-
-    if parent:
-        res = pjoin(parent, res)
-
-    if child:
-        res = pjoin(res, child)
-
-    return res
+def build_bin_path(parent: str) -> Optional[str]:
+    """Find the first bin directory recursively in the parent directory."""
+    for path, dirs, _ in os.walk(parent):
+        if "bin" in dirs:
+            return os.path.join(path, "bin")
+    return None
 
 
 def read_yaml_file(path: str) -> Dict[str, Any]:
